@@ -306,8 +306,8 @@ class DataTransformer(models.Model):
         blank = False,
         null=False
     )
-    data_transformer_parent = models.ForeignKey('self', related_name='data_transformer_parent',on_delete=models.CASCADE, blank=True, null=True, default=None)
-    data_transformer_child = models.ForeignKey('self', related_name='data_transformer_child',on_delete=models.DO_NOTHING, blank=True, null=True, default=None)
+    data_transformer_parent = models.ForeignKey('self', related_name = 'data_parent',on_delete=models.CASCADE, blank=True, null=True, default=None)
+    data_transformer_child = models.ForeignKey('self', related_name = 'data_child',on_delete=models.DO_NOTHING, blank=True, null=True, default=None)
 
     def save(self, *args, **kwargs):
         if not self.created_at:
