@@ -385,13 +385,13 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         accessory_form = AccessoryForm(instance=accessory)
         calibration_form = CalibrationForm(initial={'accessory': accessory})
 
+        if accessory.hasattr('datatransformer'):
+            data_transformer = accessory.datatransformer
+            formset = DataTransformerForm(instance=data_transformer)
+        else:
+            formset = DataTransformerForm()
 
-        data_transformer = accessory.datatransformer
-        formset = DataTransformerForm(instance=data_transformer)
 
-        if formset.is_valid():
-            formset.save()
-            return redirect('parent_view', parent_id=data_transformer.id)
         if request.accepted_renderer.format == 'html':
             return Response(
                 {"accessory_form": accessory_form, "calibration_form": calibration_form, "calibrations": calibrations, "data_transformer_form":formset},
